@@ -113,8 +113,8 @@
 autonpde<-function(namobs,namsim,iid,ix,iy,imdv=0,icens=0,icov=0, iipred=0,boolsave=TRUE,namsav="output",type.graph="eps",verbose=FALSE, calc.npde=TRUE,calc.npd=TRUE,decorr.method="cholesky",cens.method="cdf", units=list(x="",y=""), detect=FALSE, ties=TRUE,header=TRUE) {
 
    # output is deprecated, now using invisible
-  if(is.data.frame(namobs)) namobs<-deparse(substitute(namobs))
-  if(is.data.frame(namsim)) namsim<-deparse(substitute(namsim))
+#  if(is.data.frame(namobs)) namobs<-deparse(substitute(namobs))
+#  if(is.data.frame(namsim)) namsim<-deparse(substitute(namsim))
   if(missing(iid)) iid<-""
   if(missing(ix)) ix<-""
   if(missing(iy)) iy<-""
