@@ -21,7 +21,7 @@ aux.npdeplot.boxcov <- function(obsmat, pimat, plot.opt) {
           panel.grid.minor.x = element_line(ifelse(plot.opt$grid==TRUE,"grey80","white"),linetype = plot.opt$lty.grid),
           panel.grid.major.y = element_line(ifelse(plot.opt$grid==TRUE,"grey80","white"),linetype = plot.opt$lty.grid),
           panel.grid.minor.y = element_line(ifelse(plot.opt$grid==TRUE,"grey80","white"),linetype = plot.opt$lty.grid))+
-    expand_limits(y = 0) +  guides( fill = FALSE ) +
+    expand_limits(y = 0) +  guides( fill = "none" ) +
     { if(plot.opt$bands) 
       geom_point(data = pimat, aes(x = grp, y = pmid.median), color=plot.opt$col.ther, alpha = plot.opt$alpha, size=plot.opt$size.pobs)  }+
     scale_y_continuous( plot.opt$ylab, limits = y.limits, scales::pretty_breaks(n = plot.opt$breaks.y) ) +
@@ -91,8 +91,11 @@ aux.npdeplot.scatter <- function(obsmat, pimat, plot.opt) {
     x.limits = c(plot.opt$xlim[1],plot.opt$xlim[2])  else
       x.limits = c(min(obsmat$x,na.rm=TRUE),max(obsmat$x,na.rm=TRUE))
   if ("ylim" %in% names(plot.opt) & length(plot.opt$ylim)==2)
-    y.limits = c(plot.opt$ylim[1],plot.opt$ylim[2])  else
-      y.limits = c(min(pimat$pinf.lower),max(pimat$psup.upper))
+    y.limits = c(plot.opt$ylim[1],plot.opt$ylim[2])  else {
+      if(plot.opt$bands) yvec<-c(pimat$pinf.lower,pimat$psup.upper) else yvec<-c()
+      if(plot.opt$plot.obs) yvec<-c(yvec, plotdatapoint$y1,plotdatapoint2$y1)
+      if(length(yvec)>0) y.limits = c(min(yvec),max(yvec)) else y.limits<-NULL # the plot will automatically adjust
+    }
   if(plot.opt$scales %in% c("free_x", "free")) x.limits<-NULL
   if(plot.opt$scales %in% c("free_y", "free")) y.limits<-NULL
 
@@ -159,7 +162,7 @@ aux.npdeplot.scatter <- function(obsmat, pimat, plot.opt) {
               panel.grid.major.y = element_line(ifelse(plot.opt$grid==TRUE,"grey80","white"),linetype = plot.opt$lty.grid),
               panel.grid.minor.y = element_line(ifelse(plot.opt$grid==TRUE,"grey80","white"),linetype = plot.opt$lty.grid))+
         expand_limits(y = 0) +  # Eco=>Romain: not sure we want this !!! we need some kind of test (some responses may be very far from 0!!!)
-        guides( fill = FALSE ) +
+        guides( fill = "none" ) +
         
         # Model predicted and observed percentiles
         geom_line(data = pimat, mapping = aes(x = xcent, y = obs.median), inherit.aes = FALSE,
