@@ -402,6 +402,9 @@ npde.plot.data<-function(npdeObject,...) {
 #' @param npdeObject an object returned by a call to \code{\link{npde}} or \code{\link{autonpde}}
 #' @param \dots additional arguments to be passed on to the function, to control which metric (npde, pd, npd) is used or to override graphical parameters (see the PDF document for details, as well as \code{\link{set.plotoptions}})
 #' 
+#' @details By default, npd are used for the diagnostic plots. If an unknown argument to which (eg which="XXX") is given, 
+#' this is changed to npd (with a warning message if verbose=TRUE or the verbose option in the option slot of the npdeObject is TRUE).
+#' 
 #' @return a ggplot object or a list of ggplot objects (grobs)
 #' 
 #' @export
@@ -410,7 +413,7 @@ npde.plot.data<-function(npdeObject,...) {
 
 npde.plot.default<-function(npdeObject,  ...) {
   
-  # modify the plot options with the user ones (... can supersede some argumetns in plot.opt, eg covsplit to force a plot by covariates)
+  # modify the plot options with the user ones (... can supersede some arguments in plot.opt, eg covsplit to force a plot by covariates)
   userPlotOptions = list(...)
   plot.opt <- set.plotoptions.default(npdeObject)
   plot.opt <- modifyList(plot.opt, userPlotOptions[intersect(names(userPlotOptions), names(plot.opt))])
@@ -418,11 +421,14 @@ npde.plot.default<-function(npdeObject,  ...) {
   list.args<-list.args[!(names(list.args) %in% c("dist.type", "which.x", "which.y", "which"))]
   list.args$npdeObject <- npdeObject
   typmet<-intersect(plot.opt$which, c("npd","npde","pd","pde")) # check if which is one of the allowed metrics, if not set to npd
-  if(length(typmet)==0) plot.opt$which<-"npd"
+  if(length(typmet)==0) {
+    if(npdeObject@options$verbose) message(paste(plot.opt$which,"not recognised, plotting npd\n"))
+      plot.opt$which<-"npd"
+  }
 
   # Check covariate input
   if(plot.opt$covsplit) {
-    if(plot.opt$which.cov=="all") plot.opt$which.cov<-npdeObject@data@name.covariates
+    if(plot.opt$which.cov[1]=="all") plot.opt$which.cov<-npdeObject@data@name.covariates
     found.cov <- intersect(plot.opt$which.cov, npdeObject@data@name.covariates)
     if(length(found.cov)!=length(plot.opt$which.cov)) {
       if(npdeObject@options$verbose) cat("Some covariates not found, check inputs \n")
